export declare function expandHome(input: string): string;
export declare function resolveEnvValue(raw: unknown): string;
export declare function resolveEnvPlaceholders(value: string): string;
export declare function withEnvOverrides<T>(envOverrides: Record<string, string> | undefined, fn: () => Promise<T> | T): Promise<T>;
//# sourceMappingURL=env.d.ts.map