import { pathToFileURL } from 'node:url';
import { readExternalEntries } from './config/imports/external.js';
import { pathsForImport } from './config/imports/paths.js';
export { pathsForImport, readExternalEntries };
export function toFileUrl(filePath) {
    return pathToFileURL(filePath);
}
//# sourceMappingURL=config-imports.js.map