import type { Runtime } from '../runtime.js';
import type { DaemonClient } from './client.js';
interface KeepAliveRuntimeOptions {
    readonly daemonClient: DaemonClient | null;
    readonly keepAliveServers: Set<string>;
}
export declare function createKeepAliveRuntime(base: Runtime, options: KeepAliveRuntimeOptions): Runtime;
export {};
//# sourceMappingURL=runtime-wrapper.d.ts.map