import type { ConfigCliOptions } from './types.js';
export declare function handleLoginCommand(options: ConfigCliOptions, args: string[]): Promise<void>;
export declare function handleLogoutCommand(options: ConfigCliOptions, args: string[]): Promise<void>;
//# sourceMappingURL=auth.d.ts.map