interface DaemonCliOptions {
    readonly configPath: string;
    readonly rootDir?: string;
}
export declare function handleDaemonCli(args: string[], options: DaemonCliOptions): Promise<void>;
export {};
//# sourceMappingURL=daemon-command.d.ts.map