export declare function markExecutable(filePath: string): Promise<void>;
export declare function safeCopyFile(sourcePath: string, targetPath: string): Promise<void>;
//# sourceMappingURL=fs-helpers.d.ts.map