import type { CommandInput } from './types.js';
export declare function buildInlineServerDefinition(name: string, command: CommandInput, description?: string): Record<string, unknown>;
//# sourceMappingURL=server-utils.d.ts.map