import type { ServerDefinition } from './config.js';
export interface SchemaCacheSnapshot {
    readonly updatedAt: string;
    readonly tools: Record<string, unknown>;
}
export declare function resolveSchemaCacheDir(definition: ServerDefinition): string;
export declare function resolveSchemaCachePath(definition: ServerDefinition): string;
export declare function readSchemaCache(definition: ServerDefinition): Promise<SchemaCacheSnapshot | undefined>;
export declare function writeSchemaCache(definition: ServerDefinition, snapshot: SchemaCacheSnapshot): Promise<void>;
//# sourceMappingURL=schema-cache.d.ts.map