import type { ImportKind, RawEntry } from '../../config-schema.js';
interface ReadExternalEntryOptions {
    readonly projectRoot?: string;
    readonly importKind?: ImportKind;
}
export declare function readExternalEntries(filePath: string, options?: ReadExternalEntryOptions): Promise<Map<string, RawEntry> | null>;
export {};
//# sourceMappingURL=external.d.ts.map