import { getActiveLogger } from './logger-context.js';
export interface GlobalCliContext {
    readonly globalFlags: Record<string, string | undefined>;
    readonly oauthTimeoutOverride?: number;
    readonly runtimeOptions: {
        configPath?: string;
        rootDir?: string;
        logger: ReturnType<typeof getActiveLogger>;
        oauthTimeoutMs?: number;
    };
}
export declare function buildGlobalContext(argv: string[]): GlobalCliContext | {
    exit: true;
    code: number;
};
//# sourceMappingURL=cli-factory.d.ts.map