import type { OutputFormat } from './output-utils.js';
interface ConsumeOutputOptions {
    defaultFormat?: OutputFormat;
    allowed?: OutputFormat[];
    enableRawShortcut?: boolean;
    jsonShortcutFlag?: string;
}
export declare function consumeOutputFormat(args: string[], options?: ConsumeOutputOptions): OutputFormat;
export declare function isCliOutputFormat(value: string): value is OutputFormat;
export {};
//# sourceMappingURL=output-format.d.ts.map