export interface GeneratorCommonFlags {
    runtime?: 'node' | 'bun';
    timeout?: number;
    includeOptional?: boolean;
}
interface ExtractOptions {
    allowIncludeOptional?: boolean;
}
export declare function extractGeneratorFlags(args: string[], options?: ExtractOptions): GeneratorCommonFlags;
export {};
//# sourceMappingURL=flag-parser.d.ts.map