export type FlagMap = Partial<Record<string, string>>;
export declare function extractFlags(args: string[], keys: readonly string[]): FlagMap;
export declare function expectValue(flag: string, value: string | undefined): string;
//# sourceMappingURL=flag-utils.d.ts.map